/*
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.xpointer;

/**
 * Represents <KBD>root() origin() id() html()</KBD>.
 * (Based on <a href="http://www.w3.org/TR/1998/WD-xptr-19980303">WD-xptr-19980303</a>)
 *
 * @version 1.1
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 */

public class AbsTerm implements java.io.Serializable {
    int type;                                   // ST_ROOT or ST_ORIGIN or ST_ID or ST_HTML
    String param;                               // Name for id() or SkipLit for html()

    /**
     *
     * @param type XPointer.ST_ROOT / XPointer.ST_ORIGIN / XPointer.ST_ID / XPointer.ST_HTML
     * @param param ID name for "id()", name excluding quotations for "html()", <code>null</code> for others
     */
    public AbsTerm(int type, String param) {
        this.type = type;
        this.param = param;
    }

    public int getType() {
        return this.type;
    }

    public String getTypeName() {
        return XPointer.literals[this.type];
    }

    public String getParameter() {
        return this.param;
    }

    public String toString() {
        String p = "";
        if (XPointer.ST_ID == this.type)
            p = this.param;
        else if (XPointer.ST_HTML == this.type)
            p = XPointerParser.makeSkipLit(this.param);
        return XPointer.literals[this.type]+"("+p+")";
    }
}

